

Dependencies
============

The app depends on the following Python packages:

- Flask 1.0.2
- Requests 2.20.0

On the front-end side we depend on the following libraries:

- Vue 2.5.16
- Bootstrap 4.1.3
